#ifndef MyDB_H
#define OK 0
#define CREATE_ERROR 1
#define PRINT_ERROR 2
#define RECORD_SCAN_ERROR 3
#define KEY_SCAN_ERROR 4
#define INSERT_ERROR 5
#define DELETE_ERROR 6
#define MODIFY_ERROR 7


int CreateDB(char* dbName, char* datafile);
int PrintDB(char* dbName);
int RecordScan(char* dbName, int attrNumber, char* value);
int KeyScan(char*dbName, char* value);
int InsertRecord(char* dbName, char* value);
int DeleteRecord(char* dbName, char* keyValue);
int ModifyRecord(char* dbName, char* keyValue, int attrNumber, char* newValue);
void error(int rc);
#endif

